@@ -6,7 +6,7 @@
 ;; Maintainer: Protesilaos Stavrou General Issues <~protesilaos/general-issues@lists.sr.ht>
 ;; URL: https://git.sr.ht/~protesilaos/spacious-padding
 ;; Mailing-List: https://lists.sr.ht/~protesilaos/general-issues
-;; Version: 0.0.0
+;; Version: 0.1.0
 ;; Package-Requires: ((emacs "28.1"))
 ;; Keywords: convenience, focus, writing, presentation
 
@@ -27,7 +27,18 @@
 
 ;;; Commentary:
 ;;
-;; WORK-IN-PROGRESS.  Increase the padding/spacing of frames and windows.
+;; This package provides a global minor mode to increase the
+;; spacing/padding of Emacs windows and frames.  The idea is to make
+;; editing and reading feel more comfortable.  Enable the
+;; `spacious-padding-mode'.  Adjust the exact spacing values by
+;; modifying the user option `spacious-padding-widths'.
+;;
+;; Inspiration for this package comes from Nicolas Rougier's
+;; impressive designs[1] and Daniel Mendler's `org-modern`
+;; package[2]
+;;
+;; 1. <https://github.com/rougier>
+;; 2. <https://github.com/minad/org-modern>
 ;;
 ;; While obvious to everyone, here are the backronyms for this
 ;; package: Space Perception Adjusted Consistently Impacts Overall
@@ -56,7 +67,7 @@
   "Make window dividers for THEME invisible."
   (let ((bg (face-background 'default)))
     (custom-set-faces
-     `(fringe ((t :background ,bg :foreground ,bg)))
+     `(fringe ((t :background ,bg)))
      `(window-divider ((t :background ,bg :foreground ,bg)))
      `(window-divider-first-pixel ((t :background ,bg :foreground ,bg)))
      `(window-divider-last-pixel ((t :background ,bg :foreground ,bg))))))
